@@ -1,6 +1,6 @@
 import io
 import sys
-from pathlib import Path
+from pathlib import Path, PurePath
 from unittest.mock import Mock
 
 import pytest
@@ -371,7 +371,6 @@ def test_can_local(par):
 
 
 def test_mirror_from():
-
     mock = Mock()
     mock.attr = 1
 
@@ -382,7 +381,7 @@ def test_mirror_from():
             return mock
 
         def func_2(self):
-            assert False, "have to overwrite this"
+            raise AssertionError("have to overwrite this")
 
         def func_3(self):
             return "should succeed"
@@ -403,7 +402,6 @@ def test_mirror_from():
 @pytest.mark.parametrize("max_gap", [0, 32])
 @pytest.mark.parametrize("max_block", [None, 128])
 def test_merge_offset_ranges(max_gap, max_block):
-
     # Input ranges
     # (Using out-of-order ranges for full coverage)
     paths = ["foo", "bar", "bar", "bar", "foo"]
@@ -411,7 +409,11 @@ def test_merge_offset_ranges(max_gap, max_block):
     ends = [32, 32, 1024, 256, 64]
 
     # Call merge_offset_ranges
-    (result_paths, result_starts, result_ends,) = merge_offset_ranges(
+    (
+        result_paths,
+        result_starts,
+        result_ends,
+    ) = merge_offset_ranges(
         paths,
         starts,
         ends,
@@ -438,3 +440,39 @@ def test_size():
     f = io.BytesIO(b"hello")
     assert fsspec.utils.file_size(f) == 5
     assert f.tell() == 0
+
+
+class _HasFspath:
+    def __fspath__(self):
+        return "foo"
+
+
+class _HasPathAttr:
+    def __init__(self):
+        self.path = "foo"
+
+
+@pytest.mark.parametrize(
+    "path,expected",
+    [
+        # coerce to string
+        ("foo", "foo"),
+        (Path("foo"), "foo"),
+        (PurePath("foo"), "foo"),
+        (_HasFspath(), "foo"),
+        (_HasPathAttr(), "foo"),
+        # passthrough
+        (b"bytes", b"bytes"),
+        (None, None),
+        (1, 1),
+        (True, True),
+        (o := object(), o),
+        ([], []),
+        ((), ()),
+        (set(), set()),
+    ],
+)
+def test_stringify_path(path, expected):
+    path = fsspec.utils.stringify_path(path)
+
+    assert path == expected
