@@ -284,7 +284,7 @@ def read_block(
         found_end_delim = seek_delimiter(f, delimiter, 2**16)
         end = f.tell()
 
-        # Adjust split location to before delimiter iff seek found the
+        # Adjust split location to before delimiter if seek found the
         # delimiter sequence, not start or end of file.
         if found_start_delim and split_before:
             start -= len(delimiter)
@@ -350,8 +350,6 @@ def stringify_path(filepath: str | os.PathLike[str] | pathlib.Path) -> str:
         return filepath
     elif hasattr(filepath, "__fspath__"):
         return filepath.__fspath__()
-    elif isinstance(filepath, pathlib.Path):
-        return str(filepath)
     elif hasattr(filepath, "path"):
         return filepath.path
     else:
@@ -437,7 +435,7 @@ def isfilelike(f: Any) -> TypeGuard[IO[bytes]]:
 
 def get_protocol(url: str) -> str:
     url = stringify_path(url)
-    parts = re.split(r"(\:\:|\://)", url, 1)
+    parts = re.split(r"(\:\:|\://)", url, maxsplit=1)
     if len(parts) > 1:
         return parts[0]
     return "file"
